## $Id: browser.py 8020 2012-04-02 11:05:40Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from waeup.kofa.widgets.datewidget import (
    FriendlyDateWidget, FriendlyDateDisplayWidget
    )
from waeup.kofa.students.browser import (
    StudentPersonalDisplayFormPage, StudentPersonalManageFormPage,
    StudentClearanceManageFormPage, StudentClearanceEditFormPage,
    StudentClearanceDisplayFormPage, OnlinePaymentCallbackPage,
    ExportPDFClearanceSlipPage)
from waeup.kofa.students.viewlets import RequestCallbackActionButton
from waeup.uniben.students.interfaces import (
    IStudent, IStudentPersonal,
    IUGStudentClearance,IPGStudentClearance,
    )
from waeup.uniben.interfaces import MessageFactory as _

class RequestCallbackActionButton(RequestCallbackActionButton):
    """ Do not display the base package callback button in custom pages.
    """
    @property
    def target_url(self):
        return ''

class OnlinePaymentCallbackPage(OnlinePaymentCallbackPage):
    """ Neutralize callback simulation view
    """
    def update(self):
        return

class StudentPersonalDisplayFormPage(StudentPersonalDisplayFormPage):
    """ Page to display student personal data
    """
    grok.context(IStudent)
    form_fields = grok.AutoFields(IStudentPersonal)
    form_fields['perm_address'].custom_widget = BytesDisplayWidget

class StudentPersonalManageFormPage(StudentPersonalManageFormPage):
    """ Page to edit student clearance data
    """
    grok.context(IStudent)
    form_fields = grok.AutoFields(IStudentPersonal)

class StudentClearanceDisplayFormPage(StudentClearanceDisplayFormPage):
    """ Page to display student clearance data
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance).omit('clearance_locked')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance).omit('clearance_locked')
        form_fields['date_of_birth'].custom_widget = FriendlyDateDisplayWidget('le')
        return form_fields

class ExportPDFClearanceSlipPage(ExportPDFClearanceSlipPage):
    """Deliver a PDF slip of the context.
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance).omit('clearance_locked')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance).omit('clearance_locked')
        form_fields['date_of_birth'].custom_widget = FriendlyDateDisplayWidget('le')
        return form_fields

class StudentClearanceManageFormPage(StudentClearanceManageFormPage):
    """ Page to edit student clearance data
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance)
        else:
            form_fields = grok.AutoFields(IUGStudentClearance)
        form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
        return form_fields

class StudentClearanceEditFormPage(StudentClearanceEditFormPage):
    """ View to edit student clearance data by student
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance).omit('clearance_locked')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance).omit('clearance_locked')
        form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
        return form_fields

